@@ -1,23 +1,8 @@
-/*
- *  Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
- *
- * Author:  daizhengwen<daizhengwen@uniontech.com>
- *
- * Maintainer: daizhengwen<daizhengwen@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "remotemanagementpanel.h"
 #include "service.h"
 #include "utils.h"
@@ -113,12 +98,23 @@ void RemoteManagementPanel::refreshSearchState()
         m_searchEdit->hide();
     }
 
+    static bool hasStretch = false;
     if (m_listWidget->count() <= 0) {
         m_textLabel->show();
         m_imageLabel->show();
+        if (hasStretch == false) {
+            dynamic_cast<QVBoxLayout*>(this->layout())->insertLayout(3, m_backLayout);
+            dynamic_cast<QVBoxLayout*>(this->layout())->insertStretch(4);
+            hasStretch = true;
+        }
     } else {
         m_textLabel->hide();
         m_imageLabel->hide();
+        if (hasStretch == true) {
+            this->layout()->removeItem(this->layout()->itemAt(3));
+            this->layout()->removeItem(this->layout()->itemAt(3));
+            hasStretch = false;
+        }
     }
 }
 
@@ -190,8 +186,9 @@ void RemoteManagementPanel::initUI()
     m_pushButton->setText(tr("Add Server"));
 
     m_textLabel = new DLabel(this);
-    m_textLabel->setFixedSize(96, 18);
+    m_textLabel->resize(136, 18);
     m_textLabel->setText(tr("No servers yet"));
+    DFontSizeManager::instance()->bind(m_textLabel, DFontSizeManager::T6);
 
     m_imageLabel = new DLabel(this);
     m_imageLabel->setFixedSize(QSize(88, 88));
@@ -207,30 +204,24 @@ void RemoteManagementPanel::initUI()
     hlayout->setMargin(0);
 
     QHBoxLayout *textLayout = new QHBoxLayout();
-    textLayout->setContentsMargins(0, 0, 0, 0);
     textLayout->addStretch();
     textLayout->addWidget(m_textLabel);
     textLayout->addStretch();
-    textLayout->setSpacing(0);
-    textLayout->setMargin(0);
 
     QHBoxLayout *imageLayout = new QHBoxLayout();
-    imageLayout->setContentsMargins(0, 0, 0, 0);
     imageLayout->addStretch();
     imageLayout->addWidget(m_imageLabel);
     imageLayout->addStretch();
-    imageLayout->setSpacing(0);
-    imageLayout->setMargin(0);
 
-    QVBoxLayout *backLayout = new QVBoxLayout();
-    backLayout->setContentsMargins(0, 0, 0, 0);
-    backLayout->addStretch();
-    backLayout->addLayout(imageLayout);
-    backLayout->setSpacing(SPACEWIDTH);
-    backLayout->addLayout(textLayout);
-    backLayout->addStretch();
-    backLayout->setSpacing(0);
-    backLayout->setMargin(0);
+    m_backLayout = new QVBoxLayout();
+    m_backLayout->setContentsMargins(0, 0, 0, 0);
+    m_backLayout->addStretch();
+    m_backLayout->addLayout(imageLayout);
+    m_backLayout->setSpacing(SPACEWIDTH);
+    m_backLayout->addLayout(textLayout);
+    m_backLayout->addStretch();
+    m_backLayout->setSpacing(0);
+    m_backLayout->setMargin(0);
 
     QHBoxLayout *btnLayout = new QHBoxLayout();
     btnLayout->setContentsMargins(0, 0, 0, 0);
@@ -245,8 +236,6 @@ void RemoteManagementPanel::initUI()
     vlayout->addSpacing(SPACEHEIGHT);
     vlayout->addLayout(hlayout);
     vlayout->addWidget(m_listWidget);
-    vlayout->addLayout(backLayout);
-    vlayout->addStretch();
     vlayout->addLayout(btnLayout);
     vlayout->addSpacing(SPACEHEIGHT);
     vlayout->setMargin(0);
